"""add data column in annotations

Revision ID: 0010
Revises: 0009
Create Date: 2025-02-15 17:36:17.319101

"""

from collections.abc import Sequence

import sqlalchemy as sa
from alembic import op

from lilypad.server.models.base_sql_model import JSONTypeDecorator

# revision identifiers, used by Alembic.
revision: str = "0011"
down_revision: str | None = "0010"
branch_labels: str | Sequence[str] | None = None
depends_on: str | Sequence[str] | None = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table("annotations", schema=None) as batch_op:
        batch_op.add_column(sa.Column("data", JSONTypeDecorator(), nullable=True))

    with op.batch_alter_table("organizations", schema=None) as batch_op:
        batch_op.alter_column(
            "license",
            existing_type=sa.VARCHAR(),
            comment=None,
            existing_comment="License key for the organization. NULL means FREE tier",
            existing_nullable=True,
        )
        batch_op.drop_index(
            "ix_organizations_license", postgresql_where="(license IS NOT NULL)"
        )

    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table("organizations", schema=None) as batch_op:
        batch_op.create_index(
            "ix_organizations_license",
            ["license"],
            unique=True,
            postgresql_where="(license IS NOT NULL)",
        )
        batch_op.alter_column(
            "license",
            existing_type=sa.VARCHAR(),
            comment="License key for the organization. NULL means FREE tier",
            existing_nullable=True,
        )

    with op.batch_alter_table("annotations", schema=None) as batch_op:
        batch_op.drop_column("data")

    # ### end Alembic commands ###
